@@ -14,10 +14,10 @@ class GraphRenderer:
         d = Digraph()
 
         for node in sorted(self.graph.nodes):
-            d.node(name=node.path.name)
+            d.node(name=node.path.name, **node.style.to_dict())
 
         for edge in sorted(self.graph.edges):
-            d.edge(edge.tail.name, edge.head.name)
+            d.edge(edge.tail.name, edge.head.name, **edge.style.to_dict())
 
         for cluster in self.graph.clusters.values():
             cluster_renderer = ClusterRenderer(cluster)
